@@ -8,7 +8,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Exception;
 use Template ();
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 sub register {
     my ( $self, $app, $settings ) = @_;
@@ -79,10 +79,10 @@ Mojolicious::Plugin::ToolkitRenderer - Template Toolkit Renderer Mojolicious Plu
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
-=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer.svg)](https://travis-ci.org/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer)
-[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer/badge.png)](https://coveralls.io/r/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer)
+=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Mojo-Plugin-Toolkit.svg)](https://travis-ci.org/gryphonshafer/Mojo-Plugin-Toolkit)
+[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Mojo-Plugin-Toolkit/badge.png)](https://coveralls.io/r/gryphonshafer/Mojo-Plugin-Toolkit)
 
 =for test_synopsis my($self);
 
@@ -205,7 +205,7 @@ You can also look for additional information at:
 
 =item *
 
-L<GitHub|https://github.com/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer>
+L<GitHub|https://github.com/gryphonshafer/Mojo-Plugin-Toolkit>
 
 =item *
 
@@ -221,11 +221,11 @@ L<AnnoCPAN|http://annocpan.org/dist/Mojolicious-Plugin-ToolkitRenderer>
 
 =item *
 
-L<Travis CI|https://travis-ci.org/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer>
+L<Travis CI|https://travis-ci.org/gryphonshafer/Mojo-Plugin-Toolkit>
 
 =item *
 
-L<Coveralls|https://coveralls.io/r/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer>
+L<Coveralls|https://coveralls.io/r/gryphonshafer/Mojo-Plugin-Toolkit>
 
 =back
 
